"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const edge_config_1 = require("@vercel/edge-config");
class EdgeConfigStore {
    /**
     * @param edgeConfig Vercel Edge config store connection string (usually Vercel creates EDGE_CONFIG env var, this is what needed)
     * @param edgeStoreId Vercel Edge config store id
     * @param vercelApiToken  Vercel api token, used for store write operations
     */
    constructor(edgeConfig, edgeStoreId, vercelApiToken) {
        this.edgeStoreId = edgeStoreId;
        this.vercelApiToken = vercelApiToken;
        this._baseUrl = 'https://api.vercel.com/v1/edge-config/';
        this.client = (0, edge_config_1.createClient)(edgeConfig);
    }
    async get(key) {
        return (await this.client.get(key));
    }
    async set(key, value) {
        try {
            const operation = (await this.client.has(key)) ? 'update' : 'create';
            const updateEdgeConfig = await fetch(`${this._baseUrl}${this.edgeStoreId}/items`, {
                method: 'PATCH',
                headers: {
                    Authorization: `Bearer ${this.vercelApiToken}`,
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    items: [
                        {
                            operation,
                            key,
                            value,
                        },
                    ],
                }),
            });
            const result = await updateEdgeConfig.json();
            if (result.error) {
                throw new Error(result.error.message);
            }
            return result;
        }
        catch (error) {
            console.error(error);
        }
    }
}
exports.default = EdgeConfigStore;
//# sourceMappingURL=edge-config-store.js.map