import { IAssignmentLogger, IEppoClient, EppoClient } from '@eppo/js-client-sdk-common';
export { IAssignmentLogger, IAssignmentEvent, IEppoClient, IAsyncStore, } from '@eppo/js-client-sdk-common';
/**
 * Configuration used for initializing the Eppo client
 * @public
 */
export interface IClientConfig {
    /**
     * Eppo API key
     */
    apiKey: string;
    /**
     * Params for setting up connection with Vercel
     *
     * edgeConfig - string given on creation of Vercel Edge Config Store.
     * edgeConfigStoreId - id of created Vercel Edge Config Store.
     * vercelApiToken - Vercel API token with write access. Needed to write configs to Vercel Edge Config Store.
     * edgeConfigExpirationSeconds - Time during which config, stored in vercel, is valid. Defaults to 30 seconds
     */
    vercelParams: {
        edgeConfig: string;
        edgeConfigStoreId: string;
        vercelApiToken: string;
        edgeConfigExpirationSeconds?: number;
        vercelFunctionUrl?: string;
    };
    /**
     * Base URL of the Eppo API.
     * Clients should use the default setting in most cases.
     */
    baseUrl?: string;
    /**
     * Pass a logging implementation to send variation assignments to your data warehouse.
     */
    assignmentLogger: IAssignmentLogger;
    /***
     * Timeout in milliseconds for the HTTPS request for the experiment configuration. (Default: 5000)
     */
    requestTimeoutMs?: number;
    /**
     * Number of additional times the initial configuration request will be attempted if it fails.
     * This is the request typically synchronously waited (via await) for completion. A small wait will be
     * done between requests. (Default: 1)
     */
    numInitialRequestRetries?: number;
    /**
     * Throw an error if unable to fetch an initial configuration during initialization. (default: true)
     */
    throwOnFailedInitialization?: boolean;
}
/**
 * Client for assigning experiment variations.
 * @public
 */
export declare class EppoJSClient extends EppoClient {
    static instance: EppoJSClient;
    static initialized: boolean;
    getStringAssignment(flagKey: string, subjectKey: string, subjectAttributes: Record<string, string | number | boolean>, defaultValue: string): string;
    getBoolAssignment(flagKey: string, subjectKey: string, subjectAttributes: Record<string, string | number | boolean>, defaultValue: boolean): boolean;
    getIntegerAssignment(flagKey: string, subjectKey: string, subjectAttributes: Record<string, string | number | boolean>, defaultValue: number): number;
    getNumericAssignment(flagKey: string, subjectKey: string, subjectAttributes: Record<string, string | number | boolean>, defaultValue: number): number;
    getJSONAssignment(flagKey: string, subjectKey: string, subjectAttributes: Record<string, string | number | boolean>, defaultValue: object): object;
    private static getAssignmentInitializationCheck;
}
/**
 * Initializes the Eppo client with configuration parameters.
 * This method should be called once on application startup.
 * @param config - client configuration
 * @public
 */
export declare function init(config: IClientConfig): Promise<IEppoClient>;
export declare function prefetchConfig(config: IClientConfig): Promise<void>;
/**
 * Used to access a singleton SDK client instance.
 * Use the method after calling init() to initialize the client.
 * @returns a singleton client instance
 * @public
 */
export declare function getInstance(): IEppoClient;
//# sourceMappingURL=index.d.ts.map