"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const edge_config_store_1 = require("./edge-config-store");
class VercelAsyncStore {
    /**
     * @param edgeConfig Vercel Edge config store connection string (usually Vercel creates EDGE_CONFIG env var, this is what needed)
     * @param edgeStoreId Vercel Edge config store id
     * @param vercelApiToken  Vercel api token, used for store write operations
     * @param expirationTimeSeconds
     */
    constructor(edgeConfig, edgeConfigStoreId, edgeConfigToken, expirationTimeSeconds = 20) {
        this.expirationTimeSeconds = expirationTimeSeconds;
        this.storageKey = 'eppo-configuration';
        this.createdAtKey = 'eppo-configuration-created-at';
        this._isInitialized = false;
        this.client = new edge_config_store_1.default(edgeConfig, edgeConfigStoreId, edgeConfigToken);
    }
    isInitialized() {
        return this._isInitialized;
    }
    async isExpired() {
        const lastConfigCreatedAt = await this.client.get(this.createdAtKey);
        if (!lastConfigCreatedAt) {
            return true;
        }
        return lastConfigCreatedAt + this.expirationTimeSeconds * 1000 < Date.now();
    }
    async getEntries() {
        const configuration = await this.client.get(this.storageKey);
        if (!configuration) {
            return {};
        }
        return configuration;
    }
    async setEntries(entries) {
        await this.client.set(this.storageKey, entries);
        await this.client.set(this.createdAtKey, Date.now());
        this._isInitialized = true;
        return Promise.resolve();
    }
}
exports.default = VercelAsyncStore;
//# sourceMappingURL=vercel-async-store.js.map